' ########################################################################################
' * << Haru Free PDF Library 2.0.10 >> -- encoding_list.bas
' * It is provided "as is" without express or implied warranty.
' ########################################################################################

#COMPILE EXE
#DIM ALL
#INCLUDE ONCE "windows.inc"
#INCLUDE ONCE "hpdf.inc"

' ========================================================================================
' Callback error handler procedure
' ========================================================================================
SUB HPDF_Error_Handler HPDF_CALLCONV() ( _
   BYVAL error_no AS HPDF_STATUS, _
   BYVAL detail_no AS HPDF_STATUS, _
   BYVAL user_data AS DWORD)

   LOCAL strMsg AS STRING

   strMsg = "Error number = " & STR$(error_no) & " [&H" & HEX$(error_no) & "]" & $CRLF
   strMsg = strMsg & "Detail number = " & STR$(detail_no) & " [&H" & HEX$(detail_no) & "]"
   ? strMsg

END SUB
' ========================================================================================

%PAGE_WIDTH = 420
%PAGE_HEIGHT = 400
%CELL_WIDTH = 20
%CELL_HEIGHT = 20
%CELL_HEADER = 10

' ========================================================================================
' Draw the graph
' ========================================================================================
SUB draw_graph (BYVAL hPage AS HPDF_Page)

   LOCAL buf AS ASCIIZ * 50
   LOCAL i AS LONG
   LOCAL x AS LONG
   LOCAL y AS LONG

   ' /* Draw 16 X 15 cells */

   ' /* Draw vertical lines. */
   HPDF_Page_SetLineWidth (hPage, 0.5)

   FOR i = 0 TO 16
      x = i * %CELL_WIDTH + 40
      HPDF_Page_MoveTo (hPage, x, %PAGE_HEIGHT - 60)
      HPDF_Page_LineTo (hPage, x, 40)
      HPDF_Page_Stroke (hPage)
      IF i > 0 AND i <= 16 THEN
         HPDF_Page_BeginText (hPage)
         HPDF_Page_MoveTextPos (hPage, x + 5, %PAGE_HEIGHT - 75)
         buf = HEX$(i - 1)
         HPDF_Page_ShowText (hPage, buf)
         HPDF_Page_EndText (hPage)
      END IF
   NEXT

   ' /* Draw horizontal lines. */
   FOR i = 0 TO 14
      y = i * %CELL_HEIGHT + 40
      HPDF_Page_MoveTo (hPage, 40, y)
      HPDF_Page_LineTo (hPage, %PAGE_WIDTH - 40, y)
      HPDF_Page_Stroke (hPage)
      IF i < 14 THEN
         HPDF_Page_BeginText (hPage)
         HPDF_Page_MoveTextPos (hPage, 45, y + 5)
         buf = HEX$(15 - i)
         HPDF_Page_ShowText (hPage, buf)
         HPDF_Page_EndText (hPage)
      END IF
   NEXT

END SUB
' ========================================================================================

' ========================================================================================
' Draw the fonts
' ========================================================================================
SUB draw_fonts (BYVAL hPage AS HPDF_Page)

   LOCAL i AS LONG
   LOCAL j AS LONG
   LOCAL x AS LONG
   LOCAL y AS LONG
   LOCAL d AS DOUBLE
   LOCAL buf AS ASCIIZ * 2

   HPDF_Page_BeginText (hPage)

   ' /* Draw all characters from 0x20 to 0xFF to the canvas. */
   FOR i = 1 TO 16
      FOR j = 1 TO 16
         y = %PAGE_HEIGHT - 55 - ((i - 1) * %CELL_HEIGHT)
         x = j * %CELL_WIDTH + 50
          buf = CHR$((i - 1) * 16 + (j - 1))
         IF ASC(buf) >= 32 THEN
            d  = x - HPDF_Page_TextWidth (hPage, buf) / 2
            HPDF_Page_TextOut (hPage, d, y, buf)
         END IF
      NEXT
   NEXT

   HPDF_Page_EndText (hPage)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION PBMAIN

   LOCAL pdf AS HPDF_Doc
   LOCAL fname AS ASCIIZ * 256
   LOCAL hFont AS HPDF_Font
   LOCAL pv AS DWORD
   LOCAL font_name AS ASCIIZ PTR
   LOCAL i AS LONG
   LOCAL root AS HPDF_Outline
   LOCAL hPage AS HPDF_Page
   LOCAL outline AS HPDF_Outline
   LOCAL dst AS HPDF_Destination
   LOCAL hFont2 AS HPDF_Font
   DIM   encodings(0 TO 20) AS ASCIIZ * 64

   ARRAY ASSIGN encodings() = _
            "StandardEncoding", _
            "MacRomanEncoding", _
            "WinAnsiEncoding", _
            "ISO8859-2", _
            "ISO8859-3", _
            "ISO8859-4", _
            "ISO8859-5", _
            "ISO8859-9", _
            "ISO8859-10", _
            "ISO8859-13", _
            "ISO8859-14", _
            "ISO8859-15", _
            "ISO8859-16", _
            "CP1250", _
            "CP1251", _
            "CP1252", _
            "CP1254", _
            "CP1257", _
            "KOI8-R", _
            "Symbol-Set", _
            "ZapfDingbats-Set"

   fname = "encoding_list.pdf"

   pdf = HPDF_New(CODEPTR(HPDF_Error_Handler), %NULL)
   IF pdf = %NULL THEN
      ? "Error: cannot create PdfDoc object"
      EXIT FUNCTION
   END IF

   ' /* set compression mode */
   HPDF_SetCompressionMode (pdf, %HPDF_COMP_ALL)

   ' /* Set page mode to use outlines. */
   HPDF_SetPageMode(pdf, %HPDF_PAGE_MODE_USE_OUTLINE)

   ' /* get default font */
   hFont = HPDF_GetFont (pdf, "Helvetica", BYVAL %NULL)

   ' /* load font object */
   pv = HPDF_LoadType1FontFromFile (pdf, "type1/a010013l.afm", _
            "type1/a010013l.pfb")
   font_name = pv

   ' /* create outline root. */
   root = HPDF_CreateOutline (pdf, %NULL, "Encoding list", %NULL)
   HPDF_Outline_SetOpened (root, %HPDF_TRUE)

   FOR i = LBOUND(encodings) TO UBOUND(encodings)
      hPage = HPDF_AddPage (pdf)
      HPDF_Page_SetWidth (hPage, %PAGE_WIDTH)
      HPDF_Page_SetHeight (hPage, %PAGE_HEIGHT)

      outline = HPDF_CreateOutline (pdf, root, encodings(i), %NULL)
      dst = HPDF_Page_CreateDestination (hPage)

'print dst
'      HPDF_Destination_SetXYZ(dst, 0, HPDF_Page_GetHeight(hPage), 1)

local x,y,z as single
x = 0! : y = HPDF_Page_GetHeight(hPage) : z = 1!
'      HPDF_Destination_SetXYZ(dst, x, y, z)
'      HPDF_Destination_SetXYZ(dst, 0, HPDF_Page_GetHeight(hPage), 1)
      HPDF_Destination_SetXYZ(dst, 0, y, 1)

' Bug? If using v. 2.0.10 it crashes; works with v. 2.0.8

'DECLARE FUNCTION HPDF_Destination_SetXYZ LIB "libhpdf.dll" ALIAS "HPDF_Destination_SetXYZ" ( _
'   BYVAL HPDF_Destination _                   ' HPDF_Destination  dst
' , BYVAL HPDF_REAL _                          ' HPDF_REAL         left
' , BYVAL HPDF_REAL _                          ' HPDF_REAL         top
' , BYVAL HPDF_REAL _                          ' HPDF_REAL         zoom
' ) AS HPDF_STATUS                             ' HPDF_STATUS

'print "2"
      ' /* HPDF_Destination_SetFitB(dst) */
      HPDF_Outline_SetDestination(outline, dst)

      HPDF_Page_SetFontAndSize (hPage, hFont, 15)
      draw_graph (hPage)

      HPDF_Page_BeginText (hPage)
      HPDF_Page_SetFontAndSize (hPage, hFont, 20)
      HPDF_Page_MoveTextPos (hPage, 40, %PAGE_HEIGHT - 50)
      HPDF_Page_ShowText (hPage, encodings(i))
      HPDF_Page_ShowText (hPage, " Encoding")
      HPDF_Page_EndText (hPage)

      IF encodings(i) = "Symbol-Set" THEN
         hFont2 = HPDF_GetFont (pdf, "Symbol", BYVAL %NULL)
      ELSEIF encodings(i) = "ZapfDingbats-Set" THEN
         hFont2 = HPDF_GetFont (pdf, "ZapfDingbats", BYVAL %NULL)
      ELSE
         hFont2 = HPDF_GetFont (pdf, @font_name, encodings(i))
      END IF

      HPDF_Page_SetFontAndSize (hPage, hFont2, 14)
      draw_fonts (hPage)
   NEXT

   ' /* save the document to a file */
   HPDF_SaveToFile (pdf, fname)

   ' /* clean up */
   HPDF_Free (pdf)

   ? "Document created"

   #IF %DEF(%PB_CC32)
      WAITKEY$
   #ENDIF

END FUNCTION
' ========================================================================================
