'/*
' * << Haru Free PDF Library >> -- hpdf_types.h
' *
' * URL: http://libharu.org
' *
' * Copyright (c) 1999-2006 Takeshi Kanno <takeshi_kanno@est.hi-ho.ne.jp>
' * Copyright (c) 2007-2008 Antony Dovgal <tony@daylessday.org>
' *
' * Permission to use, copy, modify, distribute and sell this software
' * and its documentation for any purpose is hereby granted without fee,
' * provided that the above copyright notice appear in all copies and
' * that both that copyright notice and this permission notice appear
' * in supporting documentation.
' * It is provided "as is" without express or implied warranty.
' *
' */

#IF NOT %DEF(%HPDF_TYPES_INC)
    %HPDF_TYPES_INC = 1

'/*----------------------------------------------------------------------------*/
'/*----- type definition ------------------------------------------------------*/


'/*  native OS integer types */

MACRO HPDF_INT = LONG     ' signed int
MACRO HPDF_UINT = DWORD   ' unsigned int

'/*  32bit integer types
' */

MACRO HPDF_INT32 = LONG     ' signed int
MACRO HPDF_UINT32 = DWORD   ' unsigned int

'/*  16bit integer types
' */

MACRO HPDF_INT16 = INTEGER   ' signed short
MACRO HPDF_UINT16 = WORD     ' unsigned short

'/*  8bit integer types
' */

MACRO HPDF_INT8 = BYTE    ' signed char
MACRO HPDF_UINT8 = BYTE   ' unsigned char

'/*  8bit binary types
' */

MACRO HPDF_BYTE = BYTE   ' unsigned char

'/*  float type (32bit IEEE754)
' */

MACRO HPDF_REAL = SINGLE   ' float


'/*  double type (64bit IEEE754)
' */

MACRO HPDF_DOUBLE = DOUBLE   ' double

'/*  boolean type (0: False, !0: True)
' */

MACRO HPDF_BOOL = LONG   ' signed int


'/*  error-no type (32bit unsigned integer)
' */

MACRO HPDF_STATUS = DWORD   ' unsigned long


'/*  charactor-code type (16bit)
' */

MACRO HPDF_CID = HPDF_UINT16
MACRO HPDF_UNICODE = HPDF_UINT16


'/*  HPDF_Point struct
' */

TYPE HPDF_Point
   x AS HPDF_REAL
   y AS HPDF_REAL
END TYPE

TYPE HPDF_Rect
   left   AS HPDF_REAL
   bottom AS HPDF_REAL
   right  AS HPDF_REAL
   top    AS HPDF_REAL
END TYPE

MACRO HPDF_Box = HPDF_Rect

'/* HPDF_Date struct
' */

TYPE HPDF_Date
   year        AS HPDF_INT
   month       AS HPDF_INT
   day         AS HPDF_INT
   hour        AS HPDF_INT
   minutes     AS HPDF_INT
   seconds     AS HPDF_INT
   ind         AS BYTE       ' char
   off_hour    AS HPDF_INT
   off_minutes AS HPDF_INT
END TYPE

' Enum HPDF_InfoType
MACRO HPDF_InfoType = LONG

' /* date-time type parameters */
%HPDF_INFO_CREATION_DATE = 0
%HPDF_INFO_MOD_DATE      = 1

' /* string type parameters */
%HPDF_INFO_AUTHOR        = 2
%HPDF_INFO_CREATOR       = 3
%HPDF_INFO_PRODUCER      = 4
%HPDF_INFO_TITLE         = 5
%HPDF_INFO_SUBJECT       = 6
%HPDF_INFO_KEYWORDS      = 7
%HPDF_INFO_EOF           = 8

' Enum HPDF_PdfVer
MACRO HPDF_PdfVer = LONG

%HPDF_VER_12  = 0
%HPDF_VER_13  = 1
%HPDF_VER_14  = 2
%HPDF_VER_15  = 3
%HPDF_VER_16  = 4
%HPDF_VER_17  = 5
%HPDF_VER_EOF = 6

' Enum  HPDF_EncryptMode
MACRO HPDF_EncryptMode = LONG

%HPDF_ENCRYPT_R2 = 2
%HPDF_ENCRYPT_R3 = 3


'typedef void
'(HPDF_STDCALL *HPDF_Error_Handler)  (HPDF_STATUS   error_no,
'                                     HPDF_STATUS   detail_no,
'                                     void         *user_data);

'SUB HPDF_Error_Handler ( _
'   BYVAL error_no AS HPDF_STATUS, _
'   BYVAL detail_no AS HPDF_STATUS, _
'   BYVAL user_data AS DWORD)

'typedef void*
'(HPDF_STDCALL *HPDF_Alloc_Func)  (HPDF_UINT  size);

'SUB HPDF_Alloc_Func (BYVAL nsize AS HPDF_UINT)

'typedef void
'(HPDF_STDCALL *HPDF_Free_Func)  (void  *aptr);

'SUB HPDF_Free_Func (BYVAL aptr AS DWORD)

'/*---------------------------------------------------------------------------*/
'/*------ text width struct --------------------------------------------------*/

TYPE HPDF_TextWidth
   numchars AS HPDF_UINT
'    /* don't use this value (it may be change in the future).
'       use numspace instead. */
   numwords AS HPDF_UINT
   width    AS HPDF_UINT
   numspace AS HPDF_UINT
END TYPE

'/*---------------------------------------------------------------------------*/
'/*------ dash mode ----------------------------------------------------------*/

TYPE HPDF_DashMode
   ptn(0 TO 7) AS HPDF_UINT16
   num_ptn     AS HPDF_UINT
   phase       AS HPDF_UINT
END TYPE

'/*---------------------------------------------------------------------------*/
'/*----- HPDF_TransMatrix struct ---------------------------------------------*/

TYPE HPDF_TransMatrix
   a AS HPDF_REAL
   b AS HPDF_REAL
   c AS HPDF_REAL
   d AS HPDF_REAL
   x AS HPDF_REAL
   y AS HPDF_REAL
END TYPE

'/*---------------------------------------------------------------------------*/

' Enum HPDF_ColorSpace
MACRO HPDF_ColorSpace = LONG

%HPDF_CS_DEVICE_GRAY = 0
%HPDF_CS_DEVICE_RGB  = 1
%HPDF_CS_DEVICE_CMYK = 2
%HPDF_CS_CAL_GRAY    = 3
%HPDF_CS_CAL_RGB     = 4
%HPDF_CS_LAB         = 5
%HPDF_CS_ICC_BASED   = 6
%HPDF_CS_SEPARATION  = 7
%HPDF_CS_DEVICE_N    = 8
%HPDF_CS_INDEXED     = 9
%HPDF_CS_PATTERN     = 10
%HPDF_CS_EOF         = 11

'/*---------------------------------------------------------------------------*/
'/*----- HPDF_RGBColor struct ------------------------------------------------*/

TYPE HPDF_RGBColor
   r AS HPDF_REAL
   g AS HPDF_REAL
   b AS HPDF_REAL
END TYPE

'/*---------------------------------------------------------------------------*/
'/*----- HPDF_CMYKColor struct -----------------------------------------------*/

TYPE HPDF_CMYKColor
   c AS HPDF_REAL
   m AS HPDF_REAL
   y AS HPDF_REAL
   k AS HPDF_REAL
END TYPE

'/*---------------------------------------------------------------------------*/
'/*------ The line cap style -------------------------------------------------*/

' Enum HPDF_LineCap
MACRO HPDF_LineCap = LONG

%HPDF_BUTT_END              = 0
%HPDF_ROUND_END             = 1
%HPDF_PROJECTING_SCUARE_END = 2
%HPDF_LINECAP_EOF           = 3

'/*----------------------------------------------------------------------------*/
'/*------ The line join style -------------------------------------------------*/

' Enum _HPDF_LineJoin
MACRO HPDF_LineJoin = LONG

%HPDF_MITER_JOIN   = 0
%HPDF_ROUND_JOIN   = 1
%HPDF_BEVEL_JOIN   = 2
%HPDF_LINEJOIN_EOF = 3

'/*----------------------------------------------------------------------------*/
'/*------ The text rendering mode ---------------------------------------------*/

' Enum HPDF_TextRenderingMode
MACRO HPDF_TextRenderingMode = LONG

%HPDF_FILL                 = 0
%HPDF_STROKE               = 1
%HPDF_FILL_THEN_STROKE     = 2
%HPDF_INVISIBLE            = 3
%HPDF_FILL_CLIPPING        = 4
%HPDF_STROKE_CLIPPING      = 5
%HPDF_FILL_STROKE_CLIPPING = 6
%HPDF_CLIPPING             = 7
%HPDF_RENDERING_MODE_EOF   = 8

' Enum HPDF_WritingMode
MACRO HPDF_WritingMode = LONG

%HPDF_WMODE_HORIZONTAL = 0
%HPDF_WMODE_VERTICAL   = 1
%HPDF_WMODE_EOF        = 2

MACRO HPDF_PageLayout = LONG

%HPDF_PAGE_LAYOUT_SINGLE           = 0
%HPDF_PAGE_LAYOUT_ONE_COLUMN       = 1
%HPDF_PAGE_LAYOUT_TWO_COLUMN_LEFT  = 2
%HPDF_PAGE_LAYOUT_TWO_COLUMN_RIGHT = 3
%HPDF_PAGE_LAYOUT_EOF              = 4

' Enum HPDF_PageMode
MACRO HPDF_PageMode = LONG

%HPDF_PAGE_MODE_USE_NONE        = 0
%HPDF_PAGE_MODE_USE_OUTLINE     = 1
%HPDF_PAGE_MODE_USE_THUMBS      = 2
%HPDF_PAGE_MODE_FULL_SCREEN     = 3
'/*  HPDF_PAGE_MODE_USE_OC = 4
%HPDF_PAGE_MODE_USE_ATTACHMENTS = 4
' */
%HPDF_PAGE_MODE_EOF             = 5

' Enum HPDF_PageNumStyle
MACRO HPDF_PageNumStyle = LONG

%HPDF_PAGE_NUM_STYLE_DECIMAL       = 0
%HPDF_PAGE_NUM_STYLE_UPPER_ROMAN   = 1
%HPDF_PAGE_NUM_STYLE_LOWER_ROMAN   = 2
%HPDF_PAGE_NUM_STYLE_UPPER_LETTERS = 3
%HPDF_PAGE_NUM_STYLE_LOWER_LETTERS = 4
%HPDF_PAGE_NUM_STYLE_EOF           = 5

' Enum HPDF_DestinationType
MACRO HPDF_DestinationType = LONG

%HPDF_XYZ     = 0
%HPDF_FIT     = 1
%HPDF_FIT_H   = 2
%HPDF_FIT_V   = 3
%HPDF_FIT_R   = 4
%HPDF_FIT_B   = 5
%HPDF_FIT_BH  = 6
%HPDF_FIT_BV  = 7
%HPDF_DST_EOF = 8

' Enum _HPDF_AnnotType
MACRO HPDF_AnnotType = LONG

%HPDF_ANNOT_TEXT_NOTES      = 0
%HPDF_ANNOT_LINK            = 1
%HPDF_ANNOT_SOUND           = 2
%HPDF_ANNOT_FREE_TEXT       = 3
%HPDF_ANNOT_STAMP           = 4
%HPDF_ANNOT_SQUARE          = 5
%HPDF_ANNOT_CIRCLE          = 6
%HPDF_ANNOT_STRIKE_OUT      = 7
%HPDF_ANNOT_HIGHTLIGHT      = 8
%HPDF_ANNOT_UNDERLINE       = 9
%HPDF_ANNOT_INK             = 10
%HPDF_ANNOT_FILE_ATTACHMENT = 11
%HPDF_ANNOT_POPUP           = 12
%HPDF_ANNOT_3D              = 13

' Enum HPDF_AnnotFlgs
MACRO HPDF_AnnotFlgs = LONG

%HPDF_ANNOT_INVISIBLE = 0
%HPDF_ANNOT_HIDDEN    = 1
%HPDF_ANNOT_PRINT     = 2
%HPDF_ANNOT_NOZOOM    = 3
%HPDF_ANNOT_NOROTATE  = 4
%HPDF_ANNOT_NOVIEW    = 5
%HPDF_ANNOT_READONLY  = 6

' Enum HPDF_AnnotHighlightMode
MACRO HPDF_AnnotHighlightMode = LONG

%HPDF_ANNOT_NO_HIGHTLIGHT       = 0
%HPDF_ANNOT_INVERT_BOX          = 1
%HPDF_ANNOT_INVERT_BORDER       = 2
%HPDF_ANNOT_DOWN_APPEARANCE     = 3
%HPDF_ANNOT_HIGHTLIGHT_MODE_EOF = 4

' Enum HPDF_AnnotIcon
MACRO HPDF_AnnotIcon = LONG

%HPDF_ANNOT_ICON_COMMENT       = 0
%HPDF_ANNOT_ICON_KEY           = 1
%HPDF_ANNOT_ICON_NOTE          = 2
%HPDF_ANNOT_ICON_HELP          = 3
%HPDF_ANNOT_ICON_NEW_PARAGRAPH = 4
%HPDF_ANNOT_ICON_PARAGRAPH     = 5
%HPDF_ANNOT_ICON_INSERT        = 6
%HPDF_ANNOT_ICON_EOF           = 7


'/*----------------------------------------------------------------------------*/
'/*------ border stype --------------------------------------------------------*/

' Enum HPDF_BSSubtype
MACRO HPDF_BSSubtype = LONG

%HPDF_BS_SOLID      = 0
%HPDF_BS_DASHED     = 1
%HPDF_BS_BEVELED    = 2
%HPDF_BS_INSET      = 3
%HPDF_BS_UNDERLINED = 4

'/*----- blend modes ----------------------------------------------------------*/

' Enum HPDF_BlendMode
MACRO HPDF_BlendMode = LONG

%HPDF_BM_NORMAL      = 0
%HPDF_BM_MULTIPLY    = 1
%HPDF_BM_SCREEN      = 2
%HPDF_BM_OVERLAY     = 3
%HPDF_BM_DARKEN      = 4
%HPDF_BM_LIGHTEN     = 5
%HPDF_BM_COLOR_DODGE = 6
%HPDF_BM_COLOR_BUM   = 7
%HPDF_BM_HARD_LIGHT  = 8
%HPDF_BM_SOFT_LIGHT  = 9
%HPDF_BM_DIFFERENCE  = 10
%HPDF_BM_EXCLUSHON   = 11
%HPDF_BM_EOF         = 12

'/*----- slide show -----------------------------------------------------------*/

' Enum HPDF_TransitionStyle
MACRO HPDF_TransitionStyle = LONG

%HPDF_TS_WIPE_RIGHT                       = 0
%HPDF_TS_WIPE_UP                          = 1
%HPDF_TS_WIPE_LEFT                        = 2
%HPDF_TS_WIPE_DOWN                        = 3
%HPDF_TS_BARN_DOORS_HORIZONTAL_OUT        = 4
%HPDF_TS_BARN_DOORS_HORIZONTAL_IN         = 5
%HPDF_TS_BARN_DOORS_VERTICAL_OUT          = 6
%HPDF_TS_BARN_DOORS_VERTICAL_IN           = 7
%HPDF_TS_BOX_OUT                          = 8
%HPDF_TS_BOX_IN                           = 9
%HPDF_TS_BLINDS_HORIZONTAL                = 10
%HPDF_TS_BLINDS_VERTICAL                  = 11
%HPDF_TS_DISSOLVE                         = 12
%HPDF_TS_GLITTER_RIGHT                    = 13
%HPDF_TS_GLITTER_DOWN                     = 14
%HPDF_TS_GLITTER_TOP_LEFT_TO_BOTTOM_RIGHT = 15
%HPDF_TS_REPLACE                          = 16
%HPDF_TS_EOF                              = 17

'/*----------------------------------------------------------------------------*/

' Enum _HPDF_PageSizes
MACRO HPDF_PageSizes = LONG

%HPDF_PAGE_SIZE_LETTER    = 0
%HPDF_PAGE_SIZE_LEGAL     = 1
%HPDF_PAGE_SIZE_A3        = 2
%HPDF_PAGE_SIZE_A4        = 3
%HPDF_PAGE_SIZE_A5        = 4
%HPDF_PAGE_SIZE_B4        = 5
%HPDF_PAGE_SIZE_B5        = 6
%HPDF_PAGE_SIZE_EXECUTIVE = 7
%HPDF_PAGE_SIZE_US4x6     = 8
%HPDF_PAGE_SIZE_US4x8     = 9
%HPDF_PAGE_SIZE_US5x7     = 10
%HPDF_PAGE_SIZE_COMM10    = 11
%HPDF_PAGE_SIZE_EOF       = 12

' Enum HPDF_PageDirection
MACRO HPDF_PageDirection = LONG

%HPDF_PAGE_PORTRAIT  = 0
%HPDF_PAGE_LANDSCAPE = 1

' Enum  HPDF_EncoderType
MACRO HPDF_EncoderType = LONG

%HPDF_ENCODER_TYPE_SINGLE_BYTE   = 0
%HPDF_ENCODER_TYPE_DOUBLE_BYTE   = 1
%HPDF_ENCODER_TYPE_UNINITIALIZED = 2
%HPDF_ENCODER_UNKNOWN            = 3

' Enum HPDF_ByteType
MACRO HPDF_ByteType = LONG

%HPDF_BYTE_TYPE_SINGLE  = 0
%HPDF_BYTE_TYPE_LEAD    = 1
%HPDF_BYTE_TYPE_TRIAL   = 2
%HPDF_BYTE_TYPE_UNKNOWN = 3

' Enum HPDF_TextAlignment {
MACRO HPDF_TextAlignment = LONG

%HPDF_TALIGN_LEFT    = 0
%HPDF_TALIGN_RIGHT   = 1
%HPDF_TALIGN_CENTER  = 2
%HPDF_TALIGN_JUSTIFY = 3

#ENDIF   ' #IF NOT %DEF(%HPDF_TYPES_INC)
